@@ -21,8 +21,8 @@
  * @author Sam Meder
  *
  * $RCSfile: globus_callout.c,v $
- * $Revision: 1.25 $
- * $Date: 2011/02/03 21:46:20 $
+ * $Revision: 1.25.14.1 $
+ * $Date: 2012/02/13 14:31:04 $
  */
 
 #include "globus_common.h"
@@ -30,12 +30,8 @@
 #include "globus_i_callout.h"
 
 #ifndef BUILD_STATIC_ONLY
-#ifdef WIN32
-#include "globus_libtool_windows.h"
-#else
 #include <ltdl.h>
 #endif
-#endif
 
 #include "version.h"
 
